==> ejc-labor-impl-3.0.0-20221208.064437-204-sources.jar: com/ejianc/business/labor/bean/AttendanceEntity.java <==
package com.ejianc.business.labor.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;


/**
 * 考勤记录
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
@TableName("ejc_labor_attendance")
public class AttendanceEntity extends BaseEntity {
	private static final long serialVersionUID = -8156546740113878073L;

	@TableField(value = "worker_id")
	private Long workerId; // 劳务员工id
	@TableField(value = "project_team_id")
	private Long projectTeamId; // 项目班组
	@TableField(value = "project_team_name")
	private String projectTeamName; // 项目班组名称
	@TableField(value = "project_team_inner_code")
	private String projectTeamInnerCode; // 项目班组innerCode
	@TableField(value = "org_team_id")
	private String orgTeamId; // 公司班组
	@TableField(value = "org_team_name")
	private String orgTeamName; // 公司班组名称
	@TableField(value = "org_team_inner_code")
	private String orgTeamInnerCode; // 公司班组innerCode
	@TableField(value = "name")
	private String name; // 姓名
	@TableField(value = "id_card")
	private String idCard; // 身份证号
	@TableField(value = "phone")
	private String phone; // 手机号
	@TableField(value = "team_id")
	private String teamId; // 劳务班组
	@TableField(value = "team_name")
	private String teamName; // 劳务班组名称
	@TableField(value="work_type")
	private String workType; // 项目工种
	@TableField(value="work_type_name")
	private String workTypeName; // 项目工种名称
	@TableField(value = "org_work_type")
	private String orgWorkType; // 公司工种
	@TableField(value = "org_work_type_name")
	private String orgWorkTypeName; // 公司工种名称
	@TableField(value = "org_id")
	private Long orgId; // 组织id
	@TableField(value = "org_name")
	private String orgName; // 组织名称
	@TableField(value = "parent_org_id")
	private Long parentOrgId; // 项目部所属组织id
	@TableField(value = "parent_org_name")
	private String parentOrgName; // 项目部所属组织名称
	@TableField(value = "punch_card_date")
	private Date punchCardDate; // 打卡日期
	@TableField(value = "start_work_time")
	private Date startWorkTime; // 上班时间
	@TableField(value = "start_work_place")
	private String startWorkPlace; // 上班打卡地点
	@TableField(value = "end_work_time")
	private Date endWorkTime; // 下班时间
	@TableField(value = "end_work_place")
	private String endWorkPlace; // 下班打卡地点
	@TableField(value = "duration")
	private Long duration; // 时长
	@TableField(value = "attendance_status")
	private String attendanceStatus; // 考勤状态
	@TableField(value = "remote_flag")
	private Integer remoteFlag; // 是否是异地打卡（0：否，1:是 ）
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "project_address")
	private String projectAddress; // 项目地址
	@TableField(exist = false)
	private Integer attendanceDays; // 本期间出勤天数
	@TableField(exist = false)
	private Integer attendanceHours; // 本期间出勤时长/小时
	@TableField(exist = false)
	private Integer attendanceErrors; // 考勤异常次数


	public Long getWorkerId() {
		return workerId;
	}

	public void setWorkerId(Long workerId) {
		this.workerId = workerId;
	}

	public Long getProjectTeamId() {
		return projectTeamId;
	}

	public void setProjectTeamId(Long projectTeamId) {
		this.projectTeamId = projectTeamId;
	}

	public String getProjectTeamName() {
		return projectTeamName;
	}

	public void setProjectTeamName(String projectTeamName) {
		this.projectTeamName = projectTeamName;
	}

	public String getProjectTeamInnerCode() {
		return projectTeamInnerCode;
	}

	public void setProjectTeamInnerCode(String projectTeamInnerCode) {
		this.projectTeamInnerCode = projectTeamInnerCode;
	}

	public String getOrgTeamId() {
		return orgTeamId;
	}

	public void setOrgTeamId(String orgTeamId) {
		this.orgTeamId = orgTeamId;
	}

	public String getOrgTeamName() {
		return orgTeamName;
	}

	public void setOrgTeamName(String orgTeamName) {
		this.orgTeamName = orgTeamName;
	}

	public String getOrgTeamInnerCode() {
		return orgTeamInnerCode;
	}

	public void setOrgTeamInnerCode(String orgTeamInnerCode) {
		this.orgTeamInnerCode = orgTeamInnerCode;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getIdCard() {
		return idCard;
	}

	public void setIdCard(String idCard) {
		this.idCard = idCard;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getTeamId() {
		return teamId;
	}

	public void setTeamId(String teamId) {
		this.teamId = teamId;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public String getWorkType() {
		return workType;
	}

	public void setWorkType(String workType) {
		this.workType = workType;
	}

	public String getWorkTypeName() {
		return workTypeName;
	}

	public void setWorkTypeName(String workTypeName) {
		this.workTypeName = workTypeName;
	}

	public String getOrgWorkType() {
		return orgWorkType;
	}

	public void setOrgWorkType(String orgWorkType) {
		this.orgWorkType = orgWorkType;
	}

	public String getOrgWorkTypeName() {
		return orgWorkTypeName;
	}

	public void setOrgWorkTypeName(String orgWorkTypeName) {
		this.orgWorkTypeName = orgWorkTypeName;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public Long getParentOrgId() {
		return parentOrgId;
	}

	public void setParentOrgId(Long parentOrgId) {
		this.parentOrgId = parentOrgId;
	}

	public String getParentOrgName() {
		return parentOrgName;
	}

	public void setParentOrgName(String parentOrgName) {
		this.parentOrgName = parentOrgName;
	}

	public Date getPunchCardDate() {
		return punchCardDate;
	}

	public void setPunchCardDate(Date punchCardDate) {
		this.punchCardDate = punchCardDate;
	}

	public Date getStartWorkTime() {
		return startWorkTime;
	}

	public void setStartWorkTime(Date startWorkTime) {
		this.startWorkTime = startWorkTime;
	}

	public String getStartWorkPlace() {
		return startWorkPlace;
	}

	public void setStartWorkPlace(String startWorkPlace) {
		this.startWorkPlace = startWorkPlace;
	}

	public Date getEndWorkTime() {
		return endWorkTime;
	}

	public void setEndWorkTime(Date endWorkTime) {
		this.endWorkTime = endWorkTime;
	}

	public String getEndWorkPlace() {
		return endWorkPlace;
	}

	public void setEndWorkPlace(String endWorkPlace) {
		this.endWorkPlace = endWorkPlace;
	}

	public Long getDuration() {
		return duration;
	}

	public void setDuration(Long duration) {
		this.duration = duration;
	}

	public String getAttendanceStatus() {
		return attendanceStatus;
	}

	public void setAttendanceStatus(String attendanceStatus) {
		this.attendanceStatus = attendanceStatus;
	}

	public Integer getRemoteFlag() {
		return remoteFlag;
	}

	public void setRemoteFlag(Integer remoteFlag) {
		this.remoteFlag = remoteFlag;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getProjectAddress() {
		return projectAddress;
	}

	public void setProjectAddress(String projectAddress) {
		this.projectAddress = projectAddress;
	}

	public Integer getAttendanceDays() {
		return attendanceDays;
	}

	public void setAttendanceDays(Integer attendanceDays) {
		this.attendanceDays = attendanceDays;
	}

	public Integer getAttendanceHours() {
		return attendanceHours;
	}

	public void setAttendanceHours(Integer attendanceHours) {
		this.attendanceHours = attendanceHours;
	}

	public Integer getAttendanceErrors() {
		return attendanceErrors;
	}

	public void setAttendanceErrors(Integer attendanceErrors) {
		this.attendanceErrors = attendanceErrors;
	}
}

==> ejc-labor-impl-3.0.0-20250828.113720-345-sources.jar: com/ejianc/business/labor/bean/AttendanceEntity.java <==
package com.ejianc.business.labor.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 考勤记录
 *
 * @author baipengyan
 * @version 1.0
 * @since JDK 1.8
 */
@TableName("ejc_labor_attendance")
public class AttendanceEntity extends BaseEntity {
	private static final long serialVersionUID = -8156546740113878073L;

	@TableField(value = "worker_id")
	private Long workerId; // 劳务员工id
	@TableField(value = "project_team_id")
	private String projectTeamId; // 项目班组
	@TableField(value = "project_team_name")
	private String projectTeamName; // 项目班组名称
	@TableField(value = "project_team_inner_code")
	private String projectTeamInnerCode; // 项目班组innerCode
	@TableField(value = "org_team_id")
	private String orgTeamId; // 公司班组
	@TableField(value = "org_team_name")
	private String orgTeamName; // 公司班组名称
	@TableField(value = "org_team_inner_code")
	private String orgTeamInnerCode; // 公司班组innerCode
	@TableField(value = "name")
	private String name; // 姓名
	@TableField(value = "id_card")
	private String idCard; // 身份证号
	@TableField(value = "phone")
	private String phone; // 手机号
	@TableField(value = "team_id")
	private String teamId; // 劳务班组
	@TableField(value = "team_name")
	private String teamName; // 劳务班组名称
	@TableField(value = "work_type")
	private String workType; // 项目工种
	@TableField(value = "work_type_name")
	private String workTypeName; // 项目工种名称
	@TableField(value = "org_work_type")
	private String orgWorkType; // 公司工种
	@TableField(value = "org_work_type_name")
	private String orgWorkTypeName; // 公司工种名称
	@TableField(value = "org_id")
	private Long orgId; // 组织id
	@TableField(value = "org_name")
	private String orgName; // 组织名称
	@TableField(value = "parent_org_id")
	private Long parentOrgId; // 项目部所属组织id
	@TableField(value = "parent_org_name")
	private String parentOrgName; // 项目部所属组织名称
	@TableField(value = "punch_card_date")
	private Date punchCardDate; // 打卡日期
	@TableField(value = "start_work_time")
	private Date startWorkTime; // 上班时间
	@TableField(value = "start_work_place")
	private String startWorkPlace; // 上班打卡地点
	@TableField(value = "end_work_time")
	private Date endWorkTime; // 下班时间
	@TableField(value = "end_work_place")
	private String endWorkPlace; // 下班打卡地点
	@TableField(value = "duration")
	private Long duration; // 时长
	@TableField(value = "attendance_status")
	private String attendanceStatus; // 考勤状态
	@TableField(value = "remote_flag")
	private Integer remoteFlag; // 是否是异地打卡（0：否，1:是 ）
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "project_address")
	private String projectAddress; // 项目地址
	@TableField(exist = false)
	private BigDecimal attendanceDays; // 本期间出勤天数
	@TableField(exist = false)
	private Integer attendanceHours; // 本期间出勤时长/小时
	@TableField(exist = false)
	private Integer attendanceErrors; // 考勤异常次数
	@TableField(value = "source_id")
	private Long sourceId; // 来源id
	@TableField(value = "source_detail_id")
	private Long sourceDetailId; // 来源子表id

	@TableField(value = "actual_days")
	private BigDecimal actualDays; // 实际出勤天数 打卡记录无值默认为1天，点工单按实际录入天数，可以录入小数
	@TableField(value="remark")
	private String remark; // 备注

	@TableField(value="part_id")
	private Long partId; // 打卡部位
	@TableField(value="part_name")
	private String partName; // 打卡部位名称

	public Long getPartId() {
		return partId;
	}

	public void setPartId(Long partId) {
		this.partId = partId;
	}

	public String getPartName() {
		return partName;
	}

	public void setPartName(String partName) {
		this.partName = partName;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public BigDecimal getActualDays() {
		return actualDays;
	}

	public void setActualDays(BigDecimal actualDays) {
		this.actualDays = actualDays;
	}

	public Long getWorkerId() {
		return workerId;
	}

	public void setWorkerId(Long workerId) {
		this.workerId = workerId;
	}

	public String getProjectTeamId() {
		return projectTeamId;
	}

	public void setProjectTeamId(String projectTeamId) {
		this.projectTeamId = projectTeamId;
	}

	public String getProjectTeamName() {
		return projectTeamName;
	}

	public void setProjectTeamName(String projectTeamName) {
		this.projectTeamName = projectTeamName;
	}

	public String getProjectTeamInnerCode() {
		return projectTeamInnerCode;
	}

	public void setProjectTeamInnerCode(String projectTeamInnerCode) {
		this.projectTeamInnerCode = projectTeamInnerCode;
	}

	public String getOrgTeamId() {
		return orgTeamId;
	}

	public Long getSourceId() {
		return sourceId;
	}

	public void setSourceId(Long sourceId) {
		this.sourceId = sourceId;
	}

	public Long getSourceDetailId() {
		return sourceDetailId;
	}

	public void setSourceDetailId(Long sourceDetailId) {
		this.sourceDetailId = sourceDetailId;
	}

	public void setOrgTeamId(String orgTeamId) {
		this.orgTeamId = orgTeamId;
	}

	public String getOrgTeamName() {
		return orgTeamName;
	}

	public void setOrgTeamName(String orgTeamName) {
		this.orgTeamName = orgTeamName;
	}

	public String getOrgTeamInnerCode() {
		return orgTeamInnerCode;
	}

	public void setOrgTeamInnerCode(String orgTeamInnerCode) {
		this.orgTeamInnerCode = orgTeamInnerCode;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getIdCard() {
		return idCard;
	}

	public void setIdCard(String idCard) {
		this.idCard = idCard;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getTeamId() {
		return teamId;
	}

	public void setTeamId(String teamId) {
		this.teamId = teamId;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public String getWorkType() {
		return workType;
	}

	public void setWorkType(String workType) {
		this.workType = workType;
	}

	public String getWorkTypeName() {
		return workTypeName;
	}

	public void setWorkTypeName(String workTypeName) {
		this.workTypeName = workTypeName;
	}

	public String getOrgWorkType() {
		return orgWorkType;
	}

	public void setOrgWorkType(String orgWorkType) {
		this.orgWorkType = orgWorkType;
	}

	public String getOrgWorkTypeName() {
		return orgWorkTypeName;
	}

	public void setOrgWorkTypeName(String orgWorkTypeName) {
		this.orgWorkTypeName = orgWorkTypeName;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public Long getParentOrgId() {
		return parentOrgId;
	}

	public void setParentOrgId(Long parentOrgId) {
		this.parentOrgId = parentOrgId;
	}

	public String getParentOrgName() {
		return parentOrgName;
	}

	public void setParentOrgName(String parentOrgName) {
		this.parentOrgName = parentOrgName;
	}

	public Date getPunchCardDate() {
		return punchCardDate;
	}

	public void setPunchCardDate(Date punchCardDate) {
		this.punchCardDate = punchCardDate;
	}

	public Date getStartWorkTime() {
		return startWorkTime;
	}

	public void setStartWorkTime(Date startWorkTime) {
		this.startWorkTime = startWorkTime;
	}

	public String getStartWorkPlace() {
		return startWorkPlace;
	}

	public void setStartWorkPlace(String startWorkPlace) {
		this.startWorkPlace = startWorkPlace;
	}

	public Date getEndWorkTime() {
		return endWorkTime;
	}

	public void setEndWorkTime(Date endWorkTime) {
		this.endWorkTime = endWorkTime;
	}

	public String getEndWorkPlace() {
		return endWorkPlace;
	}

	public void setEndWorkPlace(String endWorkPlace) {
		this.endWorkPlace = endWorkPlace;
	}

	public Long getDuration() {
		return duration;
	}

	public void setDuration(Long duration) {
		this.duration = duration;
	}

	public String getAttendanceStatus() {
		return attendanceStatus;
	}

	public void setAttendanceStatus(String attendanceStatus) {
		this.attendanceStatus = attendanceStatus;
	}

	public Integer getRemoteFlag() {
		return remoteFlag;
	}

	public void setRemoteFlag(Integer remoteFlag) {
		this.remoteFlag = remoteFlag;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getProjectAddress() {
		return projectAddress;
	}

	public void setProjectAddress(String projectAddress) {
		this.projectAddress = projectAddress;
	}

	public BigDecimal getAttendanceDays() {
		return attendanceDays;
	}

	public void setAttendanceDays(BigDecimal attendanceDays) {
		this.attendanceDays = attendanceDays;
	}

	public Integer getAttendanceHours() {
		return attendanceHours;
	}

	public void setAttendanceHours(Integer attendanceHours) {
		this.attendanceHours = attendanceHours;
	}

	public Integer getAttendanceErrors() {
		return attendanceErrors;
	}

	public void setAttendanceErrors(Integer attendanceErrors) {
		this.attendanceErrors = attendanceErrors;
	}
}
